macro_rules! register_stub {
($registry:expr, $key:expr) => { ... };
}Expand description
Helper to create stub reader/writer functions for unimplemented components. These components use the Todo variant as a placeholder.
macro_rules! register_stub {
($registry:expr, $key:expr) => { ... };
}Helper to create stub reader/writer functions for unimplemented components. These components use the Todo variant as a placeholder.